<a id="autonomy.analyse.abci.handlers"></a>

# autonomy.analyse.abci.handlers

Analyse handlers.

<a id="autonomy.analyse.abci.handlers.check_handlers"></a>

#### check`_`handlers

```python
def check_handlers(config_file: Path, common_handlers: List[str], skip_skills: List[str]) -> None
```

Check handlers

